@@ -1,4 +1,7 @@
 #!/usr/bin/env python3 
+
+print("Hello World")
+
 from logic import filter_RSI, get_data_month, place_order, alpaca_connection 
 
 import pickle
@@ -13,7 +16,9 @@ from numpy.lib.npyio import load
 
 import pandas as pd
 import numpy as np
+from yfinance import ticker
 
+print("Imports Successfull")
 
 APCA_API_BASE_URL = "https://paper-api.alpaca.markets"
 
@@ -24,12 +29,17 @@ firebase_admin.initialize_app(cred)
 
 db = firestore.client()
 
+
+print("DB Initiated")
+
 # Get all Tickers
 # tickers = list(gt.get_tickers(NYSE=True, NASDAQ=True, AMEX=True))
-f = load('tickers','rb')
+f = open('tickers','rb')
 tickers = pickle.load(f)
 f.close()
 
+print(tickers)
+
 
 # Get Data for the past 30 days for all tickers
 data = get_data_month(tickers=tickers)
